@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  Copyright (C) 1994-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,13 +17,6 @@
  *
  *  Purpose: create a Dicom FileFormat or DataSet from an ASCII-dump
  *
- *  Last Update:      $Author: uli $
- *  Update Date:      $Date: 2010-10-20 07:41:34 $
- *  CVS/RCS Revision: $Revision: 1.70 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 /*
@@ -50,10 +43,10 @@
  *           separated by '\' character.  Alternatively, OB or OW values can
  *           be read from a separate file by writing the filename prefixed
  *           by a '=' character (e.g. '=largepix.dat').  The contents of the
- *           file will be read as is.  OW data is expected to be little endian
- *           ordered and will be swapped if necessary.  No checks will be made
- *           to ensure that the amount of data is reasonable in terms of other
- *           attributes such as Rows or Columns.
+ *           file will be read as is.  By default, OW data is expected to be
+ *           little endian ordered and will be swapped if necessary.  No
+ *           checks will be made to ensure that the amount of data is
+ *           reasonable in terms of other attributes such as Rows or Columns.
  *           In case of compressed pixel data, the line should start with
  *           '(7fe0,0010) OB (PixelSequence' in order to distinguish from
  *           uncompressed pixel data.
@@ -129,6 +122,9 @@ static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
 
 const unsigned int DCM_DumpMaxLineSize = 4096;
 
+// Global variables
+
+static E_ByteOrder opt_fileContentsByteOrdering = EBO_LittleEndian;
 
 // Field definition separators
 
@@ -161,12 +157,8 @@ stripWhitespace(char *s)
 static char *
 stripTrailingWhitespace(char *s)
 {
-    int i, n;
     if (s == NULL) return s;
-
-    n = strlen(s);
-    for (i = n - 1; i >= 0 && isspace(TO_UCHAR(s[i])); i--)
-        s[i] = '\0';
+    for (size_t i = strlen(s); i > 0 && isspace(TO_UCHAR(s[--i])); s[i] = '\0');
     return s;
 }
 
@@ -186,13 +178,9 @@ stripPrecedingWhitespace(char *s)
 static OFBool
 onlyWhitespace(const char *s)
 {
-    int len = strlen(s);
-    int charsFound = OFFalse;
-
-    for (int i = 0; (!charsFound) && (i < len); i++) {
-        charsFound = !isspace(TO_UCHAR(s[i]));
-    }
-    return (!charsFound) ? OFTrue : OFFalse;
+    while(*s) if (!isspace(TO_UCHAR(*s++)))
+        return OFFalse;
+    return OFTrue;
 }
 
 static char *
@@ -220,12 +208,9 @@ getLine(char *line, int maxLineLen, FILE *f, const unsigned long lineNumber)
 static OFBool
 isaCommentLine(const char *s)
 {
-    OFBool isComment = OFFalse; /* assumption */
-    int len = strlen(s);
-    int i = 0;
-    for (i = 0; i < len && isspace(TO_UCHAR(s[i])); i++) /*loop*/;
-        isComment = (s[i] == DCM_DumpCommentChar);
-    return isComment;
+    // skip leading spaces
+    while(isspace(TO_UCHAR(*s))) ++s;
+    return *s == DCM_DumpCommentChar;
 }
 
 static OFBool
@@ -240,14 +225,14 @@ parseTag(char *&s, DcmTagKey &key)
     if (p)
     {
         // string all white spaces and read tag
-        int len = p - s + 1;
+        size_t len = p - s + 1;
         p = new char[len + 1];
         OFStandard::strlcpy(p, s, len + 1);
         stripWhitespace(p);
         s += len;
 
         if (sscanf(p, "(%x,%x)", &g, &e) == 2)
-            key.set(g, e);
+            key.set(OFstatic_cast(Uint16, g), OFstatic_cast(Uint16, e));
         else
             ok = OFFalse;
         delete[] p;
@@ -296,7 +281,7 @@ parseVR(char *&s, DcmEVR &vr)
 #undef TO_UCHAR
 
 
-static int
+static size_t
 searchLastClose(char *s, const char closeChar)
 {
     // search last close bracket in a line
@@ -322,7 +307,7 @@ searchLastClose(char *s, const char closeChar)
 }
 
 
-static int
+static size_t
 searchCommentOrEol(char *s)
 {
     char *comment = strchr(s, DCM_DumpCommentChar);
@@ -335,31 +320,22 @@ searchCommentOrEol(char *s)
 }
 
 
-static char *
+static void
 convertNewlineCharacters(char *s)
 {
     // convert the string "\n" into the \r\n combination required by DICOM
-    if (s == NULL || s[0] == '\0') return s;
-    int len = strlen(s);
-    int i = 0;
-    for (i = 0; i < (len - 1); i++)
+    if (s) for (; *s; ++s) if (*s == '\\' && *(s+1) == 'n')
     {
-        if (s[i] == '\\' && s[i + 1] == 'n')
-        {
-            s[i] = '\r';
-            s[i + 1] = '\n';
-            i++;
-        }
+        *s = '\r';
+        *++s = '\n';
     }
-
-    return s;
 }
 
 static OFBool
 parseValue(char *&s, char *&value, DcmEVR &vr, const DcmTagKey &tagkey)
 {
     OFBool ok = OFTrue;
-    int len;
+    size_t len;
     value = NULL;
 
     s = stripPrecedingWhitespace(s);
@@ -374,7 +350,7 @@ parseValue(char *&s, char *&value, DcmEVR &vr, const DcmTagKey &tagkey)
             {
                 value = new char[len - 1];
                 OFStandard::strlcpy(value, s + 1, len - 1);
-                value = convertNewlineCharacters(value);
+                convertNewlineCharacters(value);
             }
             else
                 value = NULL;
@@ -458,7 +434,7 @@ putFileContentsIntoElement(DcmElement *elem, const char *filename)
     }
 
     const size_t len = OFStandard::getFileSize(filename);
-    unsigned long buflen = len;
+    size_t buflen = len;
     if (buflen & 1)
         buflen++; /* if odd then make even (DICOM requires even length values) */
 
@@ -466,18 +442,18 @@ putFileContentsIntoElement(DcmElement *elem, const char *filename)
     const DcmEVR evr = elem->getVR();
     /* create buffer of OB or OW data */
     if (evr == EVR_OB || evr == EVR_pixelItem)
-        ec = elem->createUint8Array(buflen, buf);
+        ec = elem->createUint8Array(OFstatic_cast(Uint32, buflen), buf);
     else if (evr == EVR_OW)
     {
         Uint16 *buf16 = NULL;
-        ec = elem->createUint16Array(buflen / 2, buf16);
+        ec = elem->createUint16Array(OFstatic_cast(Uint32, buflen / 2), buf16);
         buf = OFreinterpret_cast(Uint8 *, buf16);
     } else
         ec = EC_IllegalCall;
     if (ec.good())
     {
         /* read binary file into the buffer */
-        if (fread(buf, 1, OFstatic_cast(size_t, len), f) != len)
+        if (fread(buf, 1, len, f) != len)
         {
             char errBuf[256];
             OFLOG_ERROR(dump2dcmLogger, "error reading binary data file: " << filename
@@ -487,7 +463,7 @@ putFileContentsIntoElement(DcmElement *elem, const char *filename)
         else if (evr == EVR_OW)
         {
             /* swap 16 bit OW data (if necessary) */
-            swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, buf, buflen, sizeof(Uint16));
+            swapIfNecessary(gLocalByteOrder, opt_fileContentsByteOrdering, buf, OFstatic_cast(Uint32, buflen), sizeof(Uint16));
         }
     }
     else if (ec == EC_MemoryExhausted)
@@ -534,6 +510,11 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
                 << dcmvr.getVRName() << "' found, correct is '"
                 << tag.getVR().getVRName() << "'");
         }
+        else if ((tagvr == EVR_UNKNOWN) && (vr == EVR_UNKNOWN))
+        {
+            OFLOG_WARN(dump2dcmLogger, "VR of Tag " << tag << " is unknown, "
+                << "using 'UN' for this data element");
+        }
 
         if (vr != EVR_UNKNOWN)
             tag.setVR(dcmvr);
@@ -543,7 +524,7 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
         if (newTagVR == EVR_pixelSQ)
             newElement = new DcmPixelData(tag);
         else if (newTagVR == EVR_pixelItem)
-            newElement = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
+            newElement = new DcmPixelItem(DCM_PixelItemTag);
         else
             newElementError = newDicomElement(newElement, tag);
 
@@ -570,7 +551,7 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
                          * Allow a value beginning with a '=' character to represent
                          * a file containing data to be used as the attribute value.
                          * A '=' character is not a normal value since OB and OW values
-                         * must be written as multivalued hexidecimal (e.g. "00\ff\0d\8f");
+                         * must be written as multivalued hexadecimal (e.g. "00\ff\0d\8f");
                          */
                         l_error = putFileContentsIntoElement(newElement, value + 1);
                     } else {
@@ -593,7 +574,7 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
                               // special handling for pixel sequence
                               if (newTagVR == EVR_pixelSQ)
                               {
-                                  DcmPixelSequence *pixelSeq = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
+                                  DcmPixelSequence *pixelSeq = new DcmPixelSequence(DCM_PixelSequenceTag);
                                   if (pixelSeq != NULL)
                                   {
                                       OFstatic_cast(DcmPixelData *, newElement)->putOriginalRepresentation(xfer, NULL, pixelSeq);
@@ -678,8 +659,8 @@ insertIntoSet(DcmStack &stack, const E_TransferSyntax xfer, const DcmTagKey &tag
 
 static OFBool
 readDumpFile(DcmMetaInfo *metaheader, DcmDataset *dataset,
-         FILE *infile, const char *ifname, E_TransferSyntax &xfer,
-         const OFBool stopOnErrors, const unsigned long maxLineLength)
+             FILE *infile, const char *ifname, E_TransferSyntax &xfer,
+             const OFBool stopOnErrors, const unsigned long maxLineLength)
 {
     char *lineBuf = new char[maxLineLength];
     int lineNumber = 0;
@@ -702,6 +683,8 @@ readDumpFile(DcmMetaInfo *metaheader, DcmDataset *dataset,
     {
         lineNumber++;
 
+        OFLOG_TRACE(dump2dcmLogger, "processing line " << lineNumber << " of the input file");
+
         // ignore empty lines and comment lines
         if (onlyWhitespace(lineBuf))
             continue;
@@ -825,6 +808,9 @@ int main(int argc, char *argv[])
       cmd.addSubGroup("input file format:");
         cmd.addOption("--read-meta-info",      "+f",     "read meta information if present (default)");
         cmd.addOption("--ignore-meta-info",    "-f",     "ignore file meta information");
+      cmd.addSubGroup("file contents byte ordering:");
+        cmd.addOption("--read-file-little",    "+rl",    "read OW data with little endian (default)");
+        cmd.addOption("--read-file-big",       "+rb",    "read OW data from file with big endian");
       cmd.addSubGroup("other input options:");
         cmd.addOption("--line",                "+l",  1, "[m]ax-length: integer",
                                                          "maximum line length m (default: 4096)");
@@ -889,7 +875,7 @@ int main(int argc, char *argv[])
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv))
     {
       /* check exclusive options first */
       if (cmd.hasExclusiveOption())
@@ -921,6 +907,11 @@ int main(int argc, char *argv[])
       if (cmd.findOption("--ignore-meta-info")) opt_metaInfo = OFFalse;
       cmd.endOptionBlock();
 
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--read-file-little")) opt_fileContentsByteOrdering = EBO_LittleEndian;
+      if (cmd.findOption("--read-file-big")) opt_fileContentsByteOrdering = EBO_BigEndian;
+      cmd.endOptionBlock();
+
       if (cmd.findOption("--line"))
           app.checkValue(cmd.getValueAndCheckMin(opt_linelength, 80));
 
@@ -962,16 +953,8 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--enable-new-vr"))
-      {
-          dcmEnableUnknownVRGeneration.set(OFTrue);
-          dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-      }
-      if (cmd.findOption("--disable-new-vr"))
-      {
-          dcmEnableUnknownVRGeneration.set(OFFalse);
-          dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-      }
+      if (cmd.findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
+      if (cmd.findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
@@ -1113,296 +1096,3 @@ int main(int argc, char *argv[])
 
     return status;
 }
-
-
-/*
-** CVS/RCS Log:
-** $Log: dump2dcm.cc,v $
-** Revision 1.70  2010-10-20 07:41:34  uli
-** Made sure isalpha() & friends are only called with valid arguments.
-**
-** Revision 1.69  2010-10-14 13:13:30  joergr
-** Updated copyright header. Added reference to COPYRIGHT file.
-**
-** Revision 1.68  2010-06-03 10:30:17  joergr
-** Replaced calls to strerror() by new helper function OFStandard::strerror()
-** which results in using the thread safe version of strerror() if available.
-**
-** Revision 1.67  2010-05-20 09:23:45  joergr
-** Use new OFStandard::getFileSize() method where appropriate.
-**
-** Revision 1.66  2009-11-13 13:20:23  joergr
-** Fixed minor issues in log output.
-**
-** Revision 1.65  2009-11-04 09:58:06  uli
-** Switched to logging mechanism provided by the "new" oflog module
-**
-** Revision 1.64  2009-08-21 09:25:13  joergr
-** Added parameter 'writeMode' to save/write methods which allows for specifying
-** whether to write a dataset or fileformat as well as whether to update the
-** file meta information or to create a new file meta information header.
-**
-** Revision 1.63  2009-05-07 09:08:03  joergr
-** Added new command line options that allow for generating new Study/Series/SOP
-** Instance UIDs (incl. an option for overwriting existing values).
-** Added new command line options that allow for ignoring the file meta
-** information and for updating particular file meta information.
-**
-** Revision 1.62  2008-11-26 12:07:42  joergr
-** Updated documentation of newDicomElement() in order to reflect the current
-** implementation.
-**
-** Revision 1.61  2008-11-03 16:42:59  joergr
-** Added experimental support for importing very large binary files (e.g. pixel
-** data) using new createValueFromTempFile() method.
-** Added ZLIB related output options --write-xfer-deflated, --compression-level.
-**
-** Revision 1.60  2008-09-25 14:38:48  joergr
-** Moved output of resource identifier in order to avoid printing the same
-** information twice.
-**
-** Revision 1.59  2008-09-25 11:19:48  joergr
-** Added support for printing the expanded command line arguments.
-** Always output the resource identifier of the command line tool in debug mode.
-**
-** Revision 1.58  2007/06/07 09:06:01  joergr
-** Enhanced support for very large binary data elements (by reducing the overall
-** memory consumption).
-**
-** Revision 1.57  2007/03/09 15:01:02  joergr
-** Updated documentation of dump input format.
-**
-** Revision 1.56  2007/03/07 12:30:13  joergr
-** Fixed issue with uncompressed icon images in DICOM images with encapsulated
-** transfer syntax
-**
-** Revision 1.55  2007/02/22 13:07:42  joergr
-** Added support for compressed pixel data.
-** Added new command line option --write-xfer-same.
-**
-** Revision 1.54  2006/08/15 15:50:56  meichel
-** Updated all code in module dcmdata to correctly compile when
-**   all standard C++ classes remain in namespace std.
-**
-** Revision 1.53  2006/07/27 13:52:42  joergr
-** Changed parameter "exclusive" of method addOption() from type OFBool into an
-** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
-** Option "--help" is no longer an exclusive option by default.
-**
-** Revision 1.52  2006/03/23 17:16:21  joergr
-** Added missing fclose() statement at the end of main().
-**
-** Revision 1.51  2005/12/16 09:07:03  onken
-** Added variable initialization to avoid compiler warning
-**
-** Revision 1.50  2005/12/08 15:40:50  meichel
-** Changed include path schema for all DCMTK header files
-**
-** Revision 1.49  2004/07/13 09:43:10  meichel
-** Fixed memory leak occuring when raw data is read from file.
-**
-** Revision 1.48  2004/03/05 09:59:00  joergr
-** Avoid wrong warning for LUTData (0028,3006) having a VR of US or SS.
-** Added initial "hooks" for (compressed) pixel items.
-** Added "ignore errors" option (similar to dcmdump).
-**
-** Revision 1.47  2004/01/16 10:53:16  joergr
-** Adapted type casts to new-style typecast operators defined in ofcast.h.
-** Removed acknowledgements with e-mail addresses from CVS log.
-**
-** Revision 1.46  2003/11/05 16:15:27  meichel
-** Removed useless "--write-xfer-same" command line option
-**
-** Revision 1.45  2002/12/05 13:59:29  joergr
-** Fixed typo.
-**
-** Revision 1.44  2002/11/27 12:07:18  meichel
-** Adapted module dcmdata to use of new header file ofstdinc.h
-**
-** Revision 1.43  2002/11/26 08:43:02  meichel
-** Replaced all includes for "zlib.h" with <zlib.h>
-**   to avoid inclusion of zlib.h in the makefile dependencies.
-**
-** Revision 1.42  2002/09/23 17:52:04  joergr
-** Prepared code for future support of 'config.guess' host identifiers.
-**
-** Revision 1.41  2002/09/23 13:50:42  joergr
-** Added new command line option "--version" which prints the name and version
-** number of external libraries used.
-**
-** Revision 1.40  2002/08/21 10:14:16  meichel
-** Adapted code to new loadFile and saveFile methods, thus removing direct
-**   use of the DICOM stream classes.
-**
-** Revision 1.39  2002/04/16 13:38:55  joergr
-** Added configurable support for C++ ANSI standard includes (e.g. streams).
-**
-** Revision 1.38  2001/12/11 14:00:39  joergr
-** Fixed bug in 'dump2dcm' parser causing AT attribute values to be ignored.
-**
-** Revision 1.37  2001/11/09 15:50:53  joergr
-** Renamed some of the getValue/getParam methods to avoid ambiguities reported
-** by certain compilers.
-**
-** Revision 1.36  2001/09/25 17:21:01  meichel
-** Adapted dcmdata to class OFCondition
-**
-** Revision 1.35  2001/06/01 15:48:30  meichel
-** Updated copyright header
-**
-** Revision 1.34  2000/04/14 15:42:54  meichel
-** Global VR generation flags are now derived from OFGlobal and, thus,
-**   safe for use in multi-thread applications.
-**
-** Revision 1.33  2000/03/08 16:26:06  meichel
-** Updated copyright header.
-**
-** Revision 1.32  2000/03/06 18:09:38  joergr
-** Avoid empty statement in the body of if-statements (MSVC6 reports warnings).
-**
-** Revision 1.31  2000/03/03 14:05:16  meichel
-** Implemented library support for redirecting error messages into memory
-**   instead of printing them to stdout/stderr for GUI applications.
-**
-** Revision 1.30  2000/02/29 11:48:51  meichel
-** Removed support for VS value representation. This was proposed in CP 101
-**   but never became part of the standard.
-**
-** Revision 1.29  2000/02/23 15:11:36  meichel
-** Corrected macro for Borland C++ Builder 4 workaround.
-**
-** Revision 1.28  2000/02/10 16:02:51  joergr
-** Enhanced handling of PixelData/Item element. Externally stored raw data is
-** now always imported as little endian and swapped if necessary. This change
-** reflects the new 'export' feature of dcmdump.
-**
-** Revision 1.27  2000/02/01 10:11:58  meichel
-** Avoiding to include <stdlib.h> as extern "C" on Borland C++ Builder 4,
-**   workaround for bug in compiler header files.
-**
-** Revision 1.26  1999/05/03 14:13:40  joergr
-** Minor code purifications to keep Sun CC 2.0.1 quiet.
-**
-** Revision 1.25  1999/04/27 17:50:53  joergr
-** Adapted console applications to new OFCommandLine and OFConsoleApplication
-** functionality.
-**
-** Revision 1.24  1999/04/27 12:23:27  meichel
-** Prevented dcmdata applications from opening a file with empty filename,
-**   leads to application crash on Win32.
-**
-** Revision 1.23  1999/03/31 09:24:23  meichel
-** Updated copyright header in module dcmdata
-**
-** Revision 1.22  1999/03/29 10:14:15  meichel
-** Adapted command line options of dcmdata applications to new scheme.
-**
-** Revision 1.21  1999/03/22 16:16:01  meichel
-** dump2dcm now allows to include the contents of binary files
-**   as OB/OW values while converting a dump to a DICOM file.
-**
-** Revision 1.20  1999/01/07 14:13:12  meichel
-** Corrected bug in dump2dcm that prevented the correct processing of
-**   dumps created with dcmdump if they contained the "internal" VR markers
-**   "xs" (US or SS) or "ox" (OB or OW).
-**
-** Revision 1.19  1998/01/27 10:51:27  meichel
-** Removed some unused variables, meaningless const modifiers
-**   and unreached statements.
-**
-** Revision 1.18  1998/01/14 14:41:15  hewett
-** Modified existing -u command line option to also disable generation
-** of UT and VS (previously just disabled generation of UN).
-**
-** Revision 1.17  1997/08/05 07:34:54  andreas
-** Corrected Error handling of SQ in dump2dcm
-**
-** Revision 1.16  1997/07/21 07:59:02  andreas
-** - Deleted support for DcmPixelItems and DcmPixelSequences in dump2dcm
-**   ToDo: New support should be added in the future compatible to
-**   the new DcmPixel class.
-** - Replace all boolean types (BOOLEAN, CTNBOOLEAN, DICOM_BOOL, BOOL)
-**   with one unique boolean type OFBool.
-**
-** Revision 1.15  1997/07/03 15:09:40  andreas
-** - removed debugging functions Bdebug() and Edebug() since
-**   they write a static array and are not very useful at all.
-**   Cdebug and Vdebug are merged since they have the same semantics.
-**   The debugging functions in dcmdata changed their interfaces
-**   (see dcmdata/include/dcdebug.h)
-**
-** Revision 1.14  1997/05/30 06:44:57  andreas
-** - fixed scanf format problem leading to warnings on 64 bit machines.
-**
-** Revision 1.13  1997/05/29 15:52:52  meichel
-** Added constant for dcmtk release date in dcuid.h.
-** All dcmtk applications now contain a version string
-** which is displayed with the command line options ("usage" message)
-** and which can be queried in the binary with the "ident" command.
-**
-** Revision 1.12  1997/05/22 13:26:25  hewett
-** Modified the test for presence of a data dictionary to use the
-** method DcmDataDictionary::isDictionaryLoaded().
-**
-** Revision 1.11  1997/05/20 07:57:12  andreas
-** - Removed obsolete applications file2ds and ds2file. The functionality of these
-**   applications is now peformed by dcmconv. Unified calling parameters
-**   are implemented in dump2dcm, dcmdump and dcmconv.
-**
-** Revision 1.10  1997/05/16 08:31:06  andreas
-** - Revised handling of GroupLength elements and support of
-**   DataSetTrailingPadding elements. The enumeratio E_GrpLenEncoding
-**   got additional enumeration values (for a description see dctypes.h).
-**   addGroupLength and removeGroupLength methods are replaced by
-**   computeGroupLengthAndPadding. To support Padding, the parameters of
-**   element and sequence write functions changed.
-**
-** Revision 1.9  1997/04/18 08:06:56  andreas
-** - Minor corrections: correct some warnings of the SUN-C++ Compiler
-**   concerning the assignments of wrong types and inline compiler
-**   errors
-** - The put/get-methods for all VRs did not conform to the C++-Standard
-**   draft. Some Compilers (e.g. SUN-C++ Compiler, Metroworks
-**   CodeWarrier, etc.) create many warnings concerning the hiding of
-**   overloaded get methods in all derived classes of DcmElement.
-**   So the interface of all value representation classes in the
-**   library are changed rapidly, e.g.
-**   OFCondition get(Uint16 & value, const unsigned long pos);
-**   becomes
-**   OFCondition getUint16(Uint16 & value, const unsigned long pos);
-**   All (retired) "returntype get(...)" methods are deleted.
-**   For more information see dcmdata/include/dcelem.h
-**
-** Revision 1.8  1997/03/27 15:47:25  hewett
-** Added command line switche to allow generation of UN to be
-** disabled (it is enabled by default).
-**
-** Revision 1.7  1996/09/24 16:13:51  hewett
-** Added preliminary support for the Macintosh environment (GUSI library).
-**
-** Revision 1.6  1996/05/02 17:00:23  hewett
-** Corrected program name in usage description.
-**
-** Revision 1.5  1996/05/02 15:55:11  hewett
-** Stopped whitespace being stripped from inside value strings when
-** no [] delimiter present.  Now only leading and trailing whitespace
-** is stripped.
-**
-** Revision 1.4  1996/04/27 12:13:01  hewett
-** Corrected bug in last bug-fix.  A tag value [some text] was being
-** parsed as an empty string.  Now both [] and [some text] appear to
-** work as intended.
-**
-** Revision 1.3  1996/03/22 12:38:44  andreas
-** Correct some mistakes: handling [] as empty string (no value field)
-**                        handling =Name correct if Name is not correct
-**
-** Revision 1.2  1996/03/12 15:11:39  hewett
-** Added call to prepareCmdLineArgs to enable command line arguments
-** in environments which do not provide them.
-**
-** Revision 1.1  1996/01/29 13:36:38  andreas
-** dump2dcm added convert ASCII descriptions into DICOM files
-**
-**
-*/
