@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  Copyright (C) 2003-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,13 +17,6 @@
  *
  *  Purpose: Class for modifying DICOM files
  *
- *  Last Update:      $Author: uli $
- *  Update Date:      $Date: 2010-11-01 10:42:43 $
- *  CVS/RCS Revision: $Revision: 1.29 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
@@ -52,7 +45,8 @@ MdfDatasetManager::MdfDatasetManager()
 
 OFCondition MdfDatasetManager::loadFile(const char *file_name,
                                         const E_FileReadMode readMode,
-                                        const E_TransferSyntax xfer)
+                                        const E_TransferSyntax xfer,
+                                        const OFBool createIfNecessary)
 {
     OFCondition cond;
     // delete old dfile and free memory and reset current_file
@@ -61,9 +55,22 @@ OFCondition MdfDatasetManager::loadFile(const char *file_name,
     dfile = new DcmFileFormat();
     dset = dfile->getDataset();
 
-    // load file into dfile
+    // load file into dfile if it exists
     OFLOG_INFO(mdfdsmanLogger, "Loading file into dataset manager: " << file_name);
-    cond = dfile->loadFile(file_name, xfer, EGL_noChange, DCM_MaxReadLength, readMode);
+    if (OFStandard::fileExists(file_name))
+    {
+      cond = dfile->loadFile(file_name, xfer, EGL_noChange, DCM_MaxReadLength, readMode);
+    }
+    // if it does not already exist, check whether it should be created
+    else if (createIfNecessary)
+    {
+      OFLOG_DEBUG(mdfdsmanLogger, "File " << file_name << "does not exist, creating it as desired");
+      cond = dfile->saveFile(file_name, EXS_LittleEndianExplicit /* might change later */);
+    }
+    // no file, we have an error
+    else
+      cond = makeOFCondition(OFM_dcmdata, 22, OF_error,"No such file or directory");
+
     // if there are errors:
     if (cond.bad())
     {
@@ -135,7 +142,7 @@ static int readNextToken(const char *c, int& pos, DcmTagKey& key, Uint32& idx)
     unsigned int group=0;
     unsigned int elem=0;
     if (2 != sscanf(c+spos,"%x,%x", &group, &elem)) return 0; // parse error
-    key = DcmTagKey(group,elem);
+    key = DcmTagKey(OFstatic_cast(Uint16, group),OFstatic_cast(Uint16, elem));
     pos = ++lpos;
     return 1; // tag key
   }
@@ -246,7 +253,7 @@ static OFCondition splitTagPath(OFString &tag_path,
 {
     OFString target_tag;
     unsigned int group,elem;
-    int lpos,rpos;
+    size_t lpos,rpos;
     rpos=tag_path.size()-1;
     lpos=rpos;
     if (tag_path[rpos]==')')
@@ -261,12 +268,12 @@ static OFCondition splitTagPath(OFString &tag_path,
         // delete target tag from path (inclusive trailing '.')
         tag_path.erase(lpos,tag_path.length()-lpos);
         // if there's a tag path left, remove the '.', too
-        if ( (tag_path.length()>0) && (tag_path[tag_path.length()-1]=='.'))
+        if ( !tag_path.empty() && (tag_path[tag_path.length()-1]=='.'))
             tag_path.erase(tag_path.length()-1,1);
         // parse target_tag into DcmTagKey
         if (2 != sscanf(target_tag.c_str(),"(%x,%x)", &group, &elem))
             return makeOFCondition(OFM_dcmdata,22,OF_error,"Invalid target tag!");
-        key = DcmTagKey(group,elem);
+        key = DcmTagKey(OFstatic_cast(Uint16, group),OFstatic_cast(Uint16, elem));
     }
     else
     // otherwise we could have a dictionary name
@@ -299,7 +306,7 @@ OFCondition MdfDatasetManager::modifyOrInsertPath(OFString tag_path,
 {
   // if no file loaded: return an error
   if (dfile == NULL)
-      return makeOFCondition(OFM_dcmdata,22,OF_error,"No file loaded yet!");
+      return makeOFCondition(OFM_dcmdata, 22, OF_error, "No file loaded yet!");
 
   // find or create specified path
   DcmPathProcessor proc;
@@ -317,7 +324,7 @@ OFCondition MdfDatasetManager::modifyOrInsertPath(OFString tag_path,
   OFListIterator(DcmPath*) resultPath = resultPaths.begin();
   // verify that groups 0 (invalid) and 2 (meta header) were not used
   if ( (*resultPath)->containsGroup(0) || (*resultPath)->containsGroup(2) )
-      return makeOFCondition(OFM_dcmdata,22,OF_error, "Cannot insert/modify tags with group 0000 or 0002!");
+      return makeOFCondition(OFM_dcmdata, 22, OF_error, "Cannot insert/modify tags with group 0000 or 0002!");
   // also - according to the standard -  groups 1,3,5,7,FF are illegal
   if ( (*resultPath)->containsGroup(1) || (*resultPath)->containsGroup(3) ||
        (*resultPath)->containsGroup(5) || (*resultPath)->containsGroup(7) ||
@@ -332,11 +339,11 @@ OFCondition MdfDatasetManager::modifyOrInsertPath(OFString tag_path,
   if (!obj->isLeaf())
   {
       // if user specified a value to be inserted into non-leaf element, return error
-      if (value.length() != 0)
-          return makeOFCondition(OFM_dcmdata,22,OF_error,"Cannot put value into non-leaf elements!");
+      if (!value.empty())
+          return makeOFCondition(OFM_dcmdata, 22, OF_error, "Cannot put value into non-leaf elements!");
       // non-leaf elements (items/sequences) cannot just be modified
       if (only_modify)
-         return makeOFCondition(OFM_dcmdata,22,OF_error,"Cannot modify non-leaf elements!");
+         return makeOFCondition(OFM_dcmdata, 22, OF_error, "Cannot modify non-leaf elements!");
       // we have inserted an item/sequence at the end -> job completed
       return EC_Normal;
   }
@@ -435,7 +442,7 @@ OFCondition MdfDatasetManager::modifyOrInsertFromFile(OFString tag_path,
           if (fileLen & 1)
               return makeOFCondition(OFM_dcmdata, 22, OF_error, "Cannot insert/modify value with odd length from file!");
           // read element value from binary file (requires even length)
-          result = elem->createValueFromTempFile(fileStream.newFactory(), fileLen, EBO_LittleEndian);
+          result = elem->createValueFromTempFile(fileStream.newFactory(), OFstatic_cast(Uint32, fileLen), EBO_LittleEndian);
       }
       if (result.bad()) return result;
       if (update_metaheader)
@@ -524,7 +531,7 @@ OFCondition MdfDatasetManager::deleteTag(OFString tag_path,
           return makeOFCondition(OFM_dcmdata,22,OF_error, "Cannot delete tags with group 0000 or 0002!");
 
       // if tag path still contains characters, user wants to modify item tag
-      if (tag_path.length() > 0)
+      if (!tag_path.empty())
       {
           OFString error;
           DcmItem *item=NULL;
@@ -628,9 +635,18 @@ OFCondition MdfDatasetManager::saveFile(const char *file_name,
         /* check whether pixel data is compressed */
         if (opt_dataset && DcmXfer(opt_xfer).isEncapsulated())
         {
-            OFLOG_WARN(mdfdsmanLogger, "encapsulated pixel data require file format, ignoring --write-dataset");
+            OFLOG_WARN(mdfdsmanLogger, "encapsulated pixel data requires file format, ignoring --write-dataset");
             opt_dataset = OFFalse;
         }
+        /* be sure that we have a known transfer syntax. The original xfer can
+         * be unknown if the dataset was created in memory, or if the originally
+         * loaded file does not contain attributes which could make sense if
+         * it is a template file that should be processed with dcmodify.
+         */
+        if ((dfile->getDataset()->getOriginalXfer() == EXS_Unknown) && (opt_xfer  == EXS_Unknown))
+        {
+          opt_xfer = EXS_LittleEndianExplicit;
+        }
         /* write DICOM file */
         result = dfile->saveFile(file_name, opt_xfer, opt_enctype, opt_glenc,
                                  opt_padenc,
@@ -726,131 +742,3 @@ MdfDatasetManager::~MdfDatasetManager()
     // cleanup
     delete dfile;
 }
-
-
-/*
-** CVS/RCS Log:
-** $Log: mdfdsman.cc,v $
-** Revision 1.29  2010-11-01 10:42:43  uli
-** Fixed some compiler warnings reported by gcc with additional flags.
-**
-** Revision 1.28  2010-10-14 13:13:30  joergr
-** Updated copyright header. Added reference to COPYRIGHT file.
-**
-** Revision 1.27  2010-05-20 15:53:58  joergr
-** Added support for reading the value of insert/modify statements from a file.
-** Slightly modified log messages and log levels in order to be more consistent.
-** Removed some unnecessary include directives.
-**
-** Revision 1.26  2009-11-04 09:58:06  uli
-** Switched to logging mechanism provided by the "new" oflog module
-**
-** Revision 1.25  2009-08-21 09:25:13  joergr
-** Added parameter 'writeMode' to save/write methods which allows for specifying
-** whether to write a dataset or fileformat as well as whether to update the
-** file meta information or to create a new file meta information header.
-**
-** Revision 1.24  2009-07-08 16:10:36  onken
-** Adapted dcmodify to changes in DcmPath API.
-**
-** Revision 1.23  2009-01-16 10:03:13  onken
-** Code simplification for VR checking.
-**
-** Revision 1.22  2009-01-15 16:11:55  onken
-** Reworked dcmodify to work with the new DcmPath classes for supporting
-** wildcard paths and automatic insertion of missing attributes and items.
-** Added options for private tag handling and modification of UN values and
-** for ignoring errors resulting from missing tags during modify and erase
-** operations. Further cleanups.
-**
-** Revision 1.21  2006-08-15 15:50:56  meichel
-** Updated all code in module dcmdata to correctly compile when
-**   all standard C++ classes remain in namespace std.
-**
-** Revision 1.20  2005/12/16 09:08:33  onken
-** - Added variable initialization to avoid compiler warning
-**
-** Revision 1.19  2005/12/15 10:23:41  joergr
-** Replaced "true" by "OFTrue" and "false" by "OFFalse".
-**
-** Revision 1.18  2005/12/08 15:40:52  meichel
-** Changed include path schema for all DCMTK header files
-**
-** Revision 1.17  2005/12/02 09:20:08  joergr
-** Added new file read mode that makes it possible to distinguish between DICOM
-** files, datasets and other non-DICOM files.  For this reason, the last
-** parameter of method loadFile() changed from OFBool to E_FileReadMode.
-**
-** Revision 1.16  2005/11/14 15:00:14  joergr
-** Made method getFilename() const.
-**
-** Revision 1.15  2004/11/05 17:17:24  onken
-** Added input and output options for dcmodify. minor code enhancements.
-**
-** Revision 1.14  2004/10/22 16:53:26  onken
-** - fixed ignore-errors-option
-** - major enhancements for supporting private tags
-** - removed '0 Errors' output
-** - modifications to groups 0000,0001,0002,0003,0005 and 0007 are blocked,
-**   removing tags with group 0001,0003,0005 and 0007 is still possible
-** - UID options:
-**   - generate new study, series and instance UIDs
-**   - When changing UIDs in dataset, related metaheader tags are updated
-**     automatically
-** - minor code improvements
-**
-** Revision 1.13  2004/05/14 12:08:36  onken
-** Additional documentation added.
-**
-** Revision 1.12  2004/04/19 14:45:07  onken
-** Restructured code to avoid default parameter values for "complex types" like
-** OFString. Required for Sun CC 2.0.1.
-**
-** Revision 1.11  2004/04/07 12:25:53  joergr
-** Changed type of integer variables to unsigned to avoid compiler warnings
-** reported by gcc.
-**
-** Revision 1.10  2004/02/04 16:03:38  joergr
-** Removed pointer declaration from parameter "resultStack" in method
-** findAndGetElements().
-**
-** Revision 1.9  2004/01/16 10:53:53  joergr
-** Adapted type casts to new-style typecast operators defined in ofcast.h.
-**
-** Revision 1.8  2003/12/17 17:07:22  onken
-** MdfDatasetManager now remembers loaded filename. Additional save function
-** added.
-**
-** Revision 1.7  2003/12/10 16:19:20  onken
-** Changed API of MdfDatasetManager, so that its transparent for user, whether
-** he wants to modify itemtags or tags at 1. level.
-**
-** Complete rewrite of MdfConsoleEngine. It doesn't support a batchfile any more,
-** but now a user can give different modify-options at the same time on
-** commandline. Other purifications and simplifications were made.
-**
-** Revision 1.6  2003/11/11 10:55:51  onken
-** - debug-mechanism doesn't use debug(..) any more
-** - comments purified
-** - headers adjustet to debug-modifications
-**
-** Revision 1.5  2003/10/13 14:46:50  onken
-** startModify(...) simplified (uses only putString to put element-values),
-** this also allows now inserting and modifying of elements with VRM>1.
-** Method getDataset() added.
-**
-** Revision 1.4  2003/10/01 14:03:27  onken
-** Bug fixed, that excluded pixel-data when saving a file loaded into a
-** MdfDatasetManager
-**
-** Revision 1.3  2003/09/19 12:41:11  onken
-** major bugfixes, new code structure, better error-handling, corrections for "dcmtk-coding-style",Handling of VR's corrected
-**
-** Revision 1.2  2003/07/09 12:13:13  meichel
-** Included dcmodify in MSVC build system, updated headers
-**
-** Revision 1.1  2003/06/26 09:17:18  onken
-** Added commandline-application dcmodify.
-**
-**
-*/
