@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2005-2010, OFFIS e.V.
+ *  Copyright (C) 2005-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,15 +17,9 @@
  *
  *  Purpose: Convert PDF file to DICOM format
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2010-10-14 13:13:30 $
- *  CVS/RCS Revision: $Revision: 1.18 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
+
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #define INCLUDE_CSTDLIB
@@ -68,7 +62,7 @@ static OFLogger pdf2dcmLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APP
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
-OFCondition createHeader(
+static OFCondition createHeader(
   DcmItem *dataset,
   const char *opt_patientName,
   const char *opt_patientID,
@@ -109,7 +103,8 @@ OFCondition createHeader(
     // insert const value attributes
     if (result.good()) result = dataset->putAndInsertString(DCM_SpecificCharacterSet, "ISO_IR 100");
     if (result.good()) result = dataset->putAndInsertString(DCM_SOPClassUID,          UID_EncapsulatedPDFStorage);
-    if (result.good()) result = dataset->putAndInsertString(DCM_Modality,             "OT");
+    // we are now using "DOC" for the modality, which seems to be more appropriate than "OT" (see CP-749)
+    if (result.good()) result = dataset->putAndInsertString(DCM_Modality,             "DOC");
     if (result.good()) result = dataset->putAndInsertString(DCM_ConversionType,       "WSD");
     if (result.good()) result = dataset->putAndInsertString(DCM_MIMETypeOfEncapsulatedDocument, "application/pdf");
 
@@ -142,7 +137,7 @@ OFCondition createHeader(
     return result;
 }
 
-OFCondition insertPDFFile(
+static OFCondition insertPDFFile(
   DcmItem *dataset,
   const char *filename)
 {
@@ -194,9 +189,9 @@ OFCondition insertPDFFile(
     {
       if (version[i] == 10 || version[i] == 13)
       {
-      	version[i] = 0; // insert end of string
-      	found = OFTrue;
-      	break;
+        version[i] = 0; // insert end of string
+        found = OFTrue;
+        break;
       }
     }
 
@@ -220,14 +215,14 @@ OFCondition insertPDFFile(
     DcmPolymorphOBOW *elem = new DcmPolymorphOBOW(DCM_EncapsulatedDocument);
     if (elem)
     {
-      Uint32 numBytes = fileSize;
+      size_t numBytes = fileSize;
       if (numBytes & 1) ++numBytes;
       Uint8 *bytes = NULL;
-      result = elem->createUint8Array(numBytes, bytes);
+      result = elem->createUint8Array(OFstatic_cast(Uint32, numBytes), bytes);
       if (result.good())
       {
         // blank pad byte
-      	bytes[numBytes - 1] = 0;
+        bytes[numBytes - 1] = 0;
 
         // read PDF content
         if (fileSize != fread(bytes, 1, fileSize, pdffile))
@@ -248,7 +243,7 @@ OFCondition insertPDFFile(
 }
 
 
-void createIdentifiers(
+static void createIdentifiers(
   OFBool opt_readSeriesInfo,
   const char *opt_seriesFile,
   OFString& studyUID,
@@ -298,12 +293,12 @@ void createIdentifiers(
       }
     }
   }
-  if (studyUID.length() == 0)
+  if (studyUID.empty())
   {
     dcmGenerateUniqueIdentifier(buf, SITE_STUDY_UID_ROOT);
     studyUID = buf;
   }
-  if (seriesUID.length() == 0)
+  if (seriesUID.empty())
   {
     dcmGenerateUniqueIdentifier(buf, SITE_SERIES_UID_ROOT);
     seriesUID = buf;
@@ -396,7 +391,7 @@ int main(int argc, char *argv[])
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv))
     {
       /* check exclusive options first */
       if (cmd.hasExclusiveOption())
@@ -404,14 +399,11 @@ int main(int argc, char *argv[])
           if (cmd.findOption("--version"))
           {
               app.printHeader(OFTrue /*print host identifier*/);
-              ofConsole.lockCout() << OFendl << "External libraries used:";
-              ofConsole.unlockCout();
+              COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-              ofConsole.lockCout() << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
-              ofConsole.unlockCout();
+              COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-              ofConsole.lockCout() << " none" << OFendl;
-              ofConsole.unlockCout();
+              COUT << " none" << OFendl;
 #endif
               return 0;
           }
@@ -423,8 +415,7 @@ int main(int argc, char *argv[])
 
       OFLog::configureFromCommandLine(cmd, app);
 
-      dcmEnableUnknownVRGeneration.set(OFTrue);
-      dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+      dcmEnableGenerationOfNewVRs();
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--generate"))
@@ -600,74 +591,3 @@ int main(int argc, char *argv[])
 
     return 0;
 }
-
-
-/*
-** CVS/RCS Log:
-** $Log: pdf2dcm.cc,v $
-** Revision 1.18  2010-10-14 13:13:30  joergr
-** Updated copyright header. Added reference to COPYRIGHT file.
-**
-** Revision 1.17  2010-08-09 13:04:19  joergr
-** Updated data dictionary to 2009 edition of the DICOM standard. From now on,
-** the official "keyword" is used for the attribute name which results in a
-** number of minor changes (e.g. "PatientsName" is now called "PatientName").
-**
-** Revision 1.16  2009-11-13 13:20:23  joergr
-** Fixed minor issues in log output.
-**
-** Revision 1.15  2009-11-04 09:58:06  uli
-** Switched to logging mechanism provided by the "new" oflog module
-**
-** Revision 1.14  2009-10-12 09:35:43  joergr
-** Changed prefix of UIDs created for series and studies (now using constants
-** SITE_SERIES_UID_ROOT and SITE_STUDY_UID_ROOT which are supposed to be used
-** in these cases).
-**
-** Revision 1.13  2009-08-11 08:13:35  joergr
-** Slightly modified code in order to avoid warning messages on MSVC compiler.
-**
-** Revision 1.12  2009-08-10 11:04:22  joergr
-** Use helper functions checkDependence() and checkConflict() where appropriate.
-**
-** Revision 1.11  2009-08-10 10:25:23  joergr
-** Replaced '\n' by OFendl where appropriate.
-**
-** Revision 1.10  2009-04-21 14:02:49  joergr
-** Fixed minor inconsistencies in manpage / syntax usage.
-**
-** Revision 1.9  2008-09-25 14:38:48  joergr
-** Moved output of resource identifier in order to avoid printing the same
-** information twice.
-**
-** Revision 1.8  2008-09-25 11:19:48  joergr
-** Added support for printing the expanded command line arguments.
-** Always output the resource identifier of the command line tool in debug mode.
-**
-** Revision 1.7  2008-04-30 12:38:42  meichel
-** Fixed compile errors due to changes in attribute tag names
-**
-** Revision 1.6  2006/08/15 15:50:56  meichel
-** Updated all code in module dcmdata to correctly compile when
-**   all standard C++ classes remain in namespace std.
-**
-** Revision 1.5  2006/07/27 13:52:42  joergr
-** Changed parameter "exclusive" of method addOption() from type OFBool into an
-** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
-** Option "--help" is no longer an exclusive option by default.
-**
-** Revision 1.4  2005/12/08 15:40:53  meichel
-** Changed include path schema for all DCMTK header files
-**
-** Revision 1.3  2005/11/28 15:28:54  meichel
-** File dcdebug.h is not included by any other header file in the toolkit
-**   anymore, to minimize the risk of name clashes of macro debug().
-**
-** Revision 1.2  2005/10/26 13:33:49  joergr
-** Slightly modified code to use more of the "new" helper functions.
-**
-** Revision 1.1  2005/10/25 13:01:02  meichel
-** Added new tool pdf2dcm that allows to convert PDF files to DICOM
-**   Encapsulated PDF Storage SOP instances.
-**
-*/
