@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  Copyright (C) 2003-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,13 +17,6 @@
  *
  *  Purpose: Convert XML document to DICOM file or data set
  *
- *  Last Update:      $Author: uli $
- *  Update Date:      $Date: 2010-12-15 13:59:57 $
- *  CVS/RCS Revision: $Revision: 1.34 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
@@ -67,7 +60,10 @@ static xmlCharEncodingHandlerPtr EncodingHandler = NULL;
 // This function is also used in dcmsr, try to stay in sync!
 extern "C" void errorFunction(void * ctx, const char *msg, ...)
 {
+#if defined(HAVE_VSNPRINTF) && defined(HAVE_PROTOTYPE_VSNPRINTF)
+    // Classic C requires us to declare variables at the beginning of the function.
     OFString &buffer = *OFstatic_cast(OFString*, ctx);
+#endif
 
     if (!xmlLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
         return;
@@ -117,12 +113,6 @@ extern "C" void errorFunction(void * ctx, const char *msg, ...)
     // We can only show the most basic part of the message, this will look bad :(
     printf("%s", msg);
 #endif
-
-#ifndef HAVE_VSNPRINTF
-    // Only the vsnprintf() branch above uses 'buffer' which means the compiler
-    // would warn about an unused variable if HAVE_VSNPRINTF is undefined.
-    buffer += "";
-#endif
 }
 
 
@@ -185,7 +175,7 @@ static OFCondition createNewElement(xmlNodePtr current,
         unsigned int elem = 0xffff;
         if (sscanf(OFreinterpret_cast(char *, elemTag), "%x,%x", &group, &elem ) == 2)
         {
-            dcmTagKey.set(group, elem);
+            dcmTagKey.set(OFstatic_cast(Uint16, group), OFstatic_cast(Uint16, elem));
             DcmTag dcmTag(dcmTagKey);
             /* convert vr string */
             DcmVR dcmVR(OFreinterpret_cast(char *, elemVR));
@@ -251,7 +241,7 @@ static OFCondition putElementContent(xmlNodePtr current,
                 if (dcmEVR == EVR_OW)
                 {
                     /* Base64 decoder produces big endian output data, convert to local byte order */
-                    swapIfNecessary(gLocalByteOrder, EBO_BigEndian, data, length, sizeof(Uint16));
+                    swapIfNecessary(gLocalByteOrder, EBO_BigEndian, data, OFstatic_cast(Uint32, length), sizeof(Uint16));
                 }
                 result = element->putUint8Array(data, length);
                 /* delete buffer since data is copied into the element */
@@ -279,10 +269,10 @@ static OFCondition putElementContent(xmlNodePtr current,
                     if (dcmEVR == EVR_OW)
                     {
                         Uint16 *buf16 = NULL;
-                        result = element->createUint16Array(buflen / 2, buf16);
+                        result = element->createUint16Array(OFstatic_cast(Uint32, buflen / 2), buf16);
                         buf = OFreinterpret_cast(Uint8 *, buf16);
                     } else
-                        result = element->createUint8Array(buflen, buf);
+                        result = element->createUint8Array(OFstatic_cast(Uint32, buflen), buf);
                     if (result.good())
                     {
                         /* read binary file into the buffer */
@@ -297,7 +287,7 @@ static OFCondition putElementContent(xmlNodePtr current,
                         else if (dcmEVR == EVR_OW)
                         {
                             /* swap 16 bit OW data (if necessary) */
-                            swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, buf, buflen, sizeof(Uint16));
+                            swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, buf, OFstatic_cast(Uint32, buflen), sizeof(Uint16));
                         }
                     }
                     fclose(f);
@@ -309,12 +299,12 @@ static OFCondition putElementContent(xmlNodePtr current,
                 OFLOG_ERROR(xml2dcmLogger, "filename for element " << element->getTag() << " is missing, empty element inserted");
         } else {
             OFString dicomVal;
-            /* convert character set from UTF8 (for specific VRs only) */
+            /* convert character set from UTF-8 (for specific VRs only) */
             if (((dcmEVR == EVR_PN) || (dcmEVR == EVR_SH) || (dcmEVR == EVR_LO) ||
                  (dcmEVR == EVR_ST) || (dcmEVR == EVR_LT) || (dcmEVR == EVR_UT)) &&
                 (xmlStrlen(elemVal) > 0) && convertUtf8ToCharset(elemVal, dicomVal))
             {
-                result = element->putString(dicomVal.c_str());
+                result = element->putOFStringArray(dicomVal);
             } else {
                 /* set the value of the newly created element */
                 result = element->putString(OFreinterpret_cast(char *, elemVal));
@@ -444,7 +434,7 @@ static OFCondition parsePixelSequence(DcmPixelSequence *sequence,
             if (xmlStrcmp(current->name, OFreinterpret_cast(const xmlChar *, "pixel-item")) == 0)
             {
                 /* create new pixel item */
-                DcmPixelItem *newItem = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
+                DcmPixelItem *newItem = new DcmPixelItem(DCM_PixelItemTag);
                 if (newItem != NULL)
                 {
                     sequence->insert(newItem);
@@ -514,7 +504,7 @@ static OFCondition parseDataSet(DcmItem *dataset,
                     if (newElem->getTag() == DCM_PixelData)
                     {
                         /* create new pixel sequence */
-                        DcmPixelSequence *sequence = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
+                        DcmPixelSequence *sequence = new DcmPixelSequence(DCM_PixelSequenceTag);
                         if (sequence != NULL)
                         {
                             /* ... insert it into the dataset and proceed with the pixel items */
@@ -574,7 +564,15 @@ static OFCondition readXmlFile(const char *ifname,
     xfer = EXS_Unknown;
     xmlGenericError(xmlGenericErrorContext, "--- libxml parsing ------\n");
     /* build an XML tree from the file */
+#if LIBXML_VERSION >= 20703
+    /*
+     *  Starting with libxml version 2.7.3, the maximum length of XML element values
+     *  is limited to 10 MB.  The following code disables this default limitation.
+     */
+    xmlDocPtr doc = xmlReadFile(ifname, NULL /*encoding*/, XML_PARSE_HUGE);
+#else
     xmlDocPtr doc = xmlParseFile(ifname);
+#endif
     xmlGenericError(xmlGenericErrorContext, "-------------------------\n");
     if (doc != NULL)
     {
@@ -742,7 +740,7 @@ int main(int argc, char *argv[])
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv))
     {
         /* check exclusive options first */
         if (cmd.hasExclusiveOption())
@@ -755,6 +753,13 @@ int main(int argc, char *argv[])
                 COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
                 COUT << "- LIBXML, Version " << LIBXML_DOTTED_VERSION << OFendl;
+#if defined(LIBXML_ICONV_ENABLED) && defined(LIBXML_ZLIB_ENABLED)
+                COUT << "  with built-in LIBICONV and ZLIB support" << OFendl;
+#elif defined(LIBXML_ICONV_ENABLED)
+                COUT << "  with built-in LIBICONV support" << OFendl;
+#elif defined(LIBXML_ZLIB_ENABLED)
+                COUT << "  with built-in ZLIB support" << OFendl;
+#endif
                 return 0;
             }
         }
@@ -820,15 +825,9 @@ int main(int argc, char *argv[])
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--enable-new-vr"))
-        {
-            dcmEnableUnknownVRGeneration.set(OFTrue);
-            dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-        }
+            dcmEnableGenerationOfNewVRs();
         if (cmd.findOption("--disable-new-vr"))
-        {
-            dcmEnableUnknownVRGeneration.set(OFFalse);
-            dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-        }
+            dcmDisableGenerationOfNewVRs();
         cmd.endOptionBlock();
 
         cmd.beginOptionBlock();
@@ -989,126 +988,3 @@ int main(int, char *[])
 }
 
 #endif /* WITH_LIBXML */
-
-
-/*
- * CVS/RCS Log:
- * $Log: xml2dcm.cc,v $
- * Revision 1.34  2010-12-15 13:59:57  uli
- * Fixed a problem with a missing prototype for vsnprintf on HP-UX.
- *
- * Revision 1.33  2010-10-21 08:35:41  joergr
- * Removed redundant definition of logger variable for libxml.
- *
- * Revision 1.32  2010-10-14 13:13:30  joergr
- * Updated copyright header. Added reference to COPYRIGHT file.
- *
- * Revision 1.31  2010-06-03 10:30:17  joergr
- * Replaced calls to strerror() by new helper function OFStandard::strerror()
- * which results in using the thread safe version of strerror() if available.
- *
- * Revision 1.30  2010-05-20 09:22:31  joergr
- * Use new OFStandard::getFileSize() method where appropriate.
- *
- * Revision 1.29  2009-11-13 13:20:23  joergr
- * Fixed minor issues in log output.
- *
- * Revision 1.28  2009-11-04 09:58:06  uli
- * Switched to logging mechanism provided by the "new" oflog module
- *
- * Revision 1.27  2009-08-21 09:25:13  joergr
- * Added parameter 'writeMode' to save/write methods which allows for specifying
- * whether to write a dataset or fileformat as well as whether to update the
- * file meta information or to create a new file meta information header.
- *
- * Revision 1.26  2009-05-07 09:05:09  joergr
- * Added new command line options that allow for generating new Study/Series/SOP
- * Instance UIDs (incl. an option for overwriting existing values).
- *
- * Revision 1.25  2009-04-30 14:56:39  joergr
- * Fixed memory leak in putElementContent() for base64 encoded data.
- *
- * Revision 1.24  2008-11-03 15:50:42  joergr
- * Added ZLIB related output options --write-xfer-deflated, --compression-level.
- *
- * Revision 1.23  2008-09-25 14:38:48  joergr
- * Moved output of resource identifier in order to avoid printing the same
- * information twice.
- *
- * Revision 1.22  2008-09-25 11:19:48  joergr
- * Added support for printing the expanded command line arguments.
- * Always output the resource identifier of the command line tool in debug mode.
- *
- * Revision 1.21  2008-09-24 13:00:48  joergr
- * Added new command line option --update-meta-info that allows for updating
- * particular information in the file meta-header (e.g. SOP instance UID).
- *
- * Revision 1.20  2007/07/04 12:51:05  joergr
- * Added support for binary data (e.g. pixel data) stored in a separate file.
- *
- * Revision 1.19  2006/08/15 15:50:56  meichel
- * Updated all code in module dcmdata to correctly compile when
- *   all standard C++ classes remain in namespace std.
- *
- * Revision 1.18  2006/07/27 13:52:42  joergr
- * Changed parameter "exclusive" of method addOption() from type OFBool into an
- * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
- * Option "--help" is no longer an exclusive option by default.
- *
- * Revision 1.17  2006/07/11 13:59:20  joergr
- * Fixed wrong warning message about multiple Specific Character Set attributes
- * in DICOMDIR files.
- *
- * Revision 1.16  2005/12/16 15:46:41  meichel
- * Declared libxml2 callback functions as extern "C"
- *
- * Revision 1.15  2005/12/09 12:38:51  meichel
- * Added missing include for dcdebug.h
- *
- * Revision 1.14  2005/12/08 15:40:54  meichel
- * Changed include path schema for all DCMTK header files
- *
- * Revision 1.13  2005/11/30 12:51:45  joergr
- * Added missing header file "dcdebug.h".
- *
- * Revision 1.12  2005/03/22 13:55:50  joergr
- * Added call of macro LIBXML_TEST_VERSION.
- *
- * Revision 1.11  2004/11/29 17:04:08  joergr
- * Added support for UTF-8 character set.
- *
- * Revision 1.10  2004/08/03 10:06:18  joergr
- * Added new option that allows to ignore the file meta information.
- *
- * Revision 1.9  2004/03/25 17:27:36  joergr
- * Solved issue with function pointer to std::fprintf or fprintf, respectively.
- *
- * Revision 1.8  2004/03/22 16:55:11  joergr
- * Replaced tabs by spaces.
- *
- * Revision 1.7  2004/02/20 18:06:43  joergr
- * Avoid wrong warning for LUTData (0028,3006) having a VR of US or SS.
- *
- * Revision 1.6  2004/01/16 10:53:53  joergr
- * Adapted type casts to new-style typecast operators defined in ofcast.h.
- *
- * Revision 1.5  2003/08/08 14:46:24  joergr
- * Made libxml output consistent with new xml2dsr command line tool.
- *
- * Revision 1.4  2003/06/17 17:36:04  joergr
- * Distinguish more strictly between OFBool and int (required when HAVE_CXX_BOOL
- * is defined).
- *
- * Revision 1.3  2003/05/20 08:52:56  joergr
- * Minor code corrections.
- *
- * Revision 1.2  2003/04/22 08:25:48  joergr
- * Adapted code to also compile trouble-free without libxml support (report a
- * message that libxml library is required).
- *
- * Revision 1.1  2003/04/17 18:57:08  joergr
- * Added new command line tool that allows to convert an XML document to DICOM
- * file or dataset.
- *
- *
- */
