@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  Copyright (C) 1994-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,13 +17,6 @@
  *
  *  Purpose: Interface of class DcmDirectoryRecord
  *
- *  Last Update:      $Author: uli $
- *  Update Date:      $Date: 2010-11-15 13:58:43 $
- *  CVS/RCS Revision: $Revision: 1.47 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 #ifndef DCDIRREC_H
@@ -125,7 +118,11 @@ typedef enum {
     /// implant group
     ERT_ImplantGroup = 42,
     /// implant assembly
-    ERT_ImplantAssy = 43
+    ERT_ImplantAssy = 43,
+    /// plan
+    ERT_Plan = 44,
+    /// surface scan
+    ERT_SurfaceScan = 45
 } E_DirRecType;
 
 
@@ -133,7 +130,7 @@ class DcmDicomDir;
 
 /** a class representing a directory record dataset in a DICOMDIR.
  */
-class DcmDirectoryRecord : public DcmItem
+class DCMTK_DCMDATA_EXPORT DcmDirectoryRecord : public DcmItem
 {
 
     friend class DcmDicomDir;
@@ -153,19 +150,23 @@ public:
      *  @param recordType record type
      *  @param referencedFileID referenced file ID in DICOM format
      *  @param sourceFileName path to referenced file in operating system specific format
+     *  @param fileFormat fileFormat for sourceFileName, can be NULL
      */
     DcmDirectoryRecord(const E_DirRecType recordType,
-                       const char *referencedFileID,   // DICOM format with '\\'
-                       const char *sourceFileName);    // OS Format
+                       const char *referencedFileID,     // DICOM format with '\\'
+                       const OFFilename &sourceFileName, // OS format
+                       DcmFileFormat* fileFormat = NULL);
 
     /** constructor
      *  @param recordTypeName record type as string
      *  @param referencedFileID referenced file ID in DICOM format
      *  @param sourceFileName path to referenced file in operating system specific format
+     *  @param fileFormat fileFormat for sourceFileName, can be NULL
      */
     DcmDirectoryRecord(const char *recordTypeName,
-                       const char *referencedFileID,   // DICOM Format with '\\'
-                       const char *sourceFileName);    // OS Format
+                       const char *referencedFileID,     // DICOM format with '\\'
+                       const OFFilename &sourceFileName, // OS format
+                       DcmFileFormat* fileFormat = NULL);
 
     /** copy constructor
      *  @param oldDirRec element to be copied
@@ -213,6 +214,77 @@ public:
     /// returns current status flag
     inline OFCondition error() const { return errorFlag; }
 
+    /** mode specifying whether the SpecificCharacterSet (0008,0005) element should be
+     *  checked by convertCharacterSet() or not, i.e.\ whether this element might be
+     *  present on this dataset-level.
+     *  @return always returns OFTrue, i.e.\ SpecificCharacterSet should be checked
+     */
+    virtual OFBool checkForSpecificCharacterSet() const { return OFTrue; }
+
+    /** convert all element values that are contained in this record and that are
+     *  affected by SpecificCharacterSet from the given source character set to the given
+     *  destination character set. The defined terms for a particular character set can
+     *  be found in the DICOM standard, e.g. "ISO_IR 100" for ISO 8859-1 (Latin 1) or
+     *  "ISO_IR 192" for Unicode in UTF-8. An empty string denotes the default character
+     *  repertoire, which is ASCII (7-bit). If multiple values are given for 'fromCharset'
+     *  (separated by a backslash) code extension techniques are used and escape sequences
+     *  may be encountered in the source string to switch between the specified character
+     *  sets.
+     *  @param fromCharset name of the source character set(s) used for the conversion
+     *  @param toCharset name of the destination character set used for the conversion.
+     *    Only a single value is permitted (i.e. no code extensions).
+     *  @param transliterate mode specifying whether a character that cannot be
+     *    represented in the destination character encoding is approximated through one
+     *    or more characters that look similar to the original one
+     *  @param updateCharset if OFTrue, the SpecificCharacterSet (0008,0005) element is
+     *    updated, i.e.\ the current value is either replaced or a new element is inserted
+     *    or the existing element is deleted. If OFFalse the SpecificCharacterSet element
+     *    remains unchanged.
+     *  @param discardIllegal mode specifying whether characters that cannot be represented
+     *    in the destination character encoding will be silently discarded
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition convertCharacterSet(const OFString &fromCharset,
+                                            const OFString &toCharset,
+                                            const OFBool transliterate = OFFalse,
+                                            const OFBool updateCharset = OFFalse,
+                                            const OFBool discardIllegal = OFFalse);
+
+    /** convert all element values that are contained in this record and that are
+     *  affected by SpecificCharacterSet to the given destination character set. If not
+     *  disabled, the source character set is determined automatically from the value of
+     *  the SpecificCharacterSet (0008,0005) element. The defined terms for the
+     *  destination character set can be found in the DICOM standard, e.g. "ISO_IR 100"
+     *  for ISO 8859-1 (Latin 1) or "ISO_IR 192" for Unicode in UTF-8. An empty string
+     *  denotes the default character repertoire, which is ASCII (7-bit).
+     *  @param toCharset name of the destination character set used for the conversion.
+     *    Only a single value is permitted (i.e. no code extensions).
+     *  @param transliterate mode specifying whether a character that cannot be
+     *    represented in the destination character encoding is approximated through one
+     *    or more characters that look similar to the original one
+     *  @param ignoreCharset if OFTrue, the value of SpecificCharacterSet is ignored.
+     *    Also see checkForSpecificCharacterSet().
+     *  @param discardIllegal mode specifying whether characters that cannot be represented
+     *    in the destination character encoding will be silently discarded
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition convertCharacterSet(const OFString &toCharset,
+                                            const OFBool transliterate = OFFalse,
+                                            const OFBool ignoreCharset = OFFalse,
+                                            const OFBool discardIllegal = OFFalse);
+
+    /** convert all element values that are contained in this record and that are
+     *  affected by SpecificCharacterSet from the currently selected source character
+     *  set to the currently selected destination character set. Since the Basic
+     *  Directory IOD, which specifies the structure and content of a DICOMDIR, does not
+     *  contain the SpecificCharacterSet (0008,0005) element in the main dataset but in
+     *  each directory record, this method also checks for this element and creates a new
+     *  character set converter for the contained data elements (if needed).
+     *  @param converter character set converter to be used to convert the element values
+     *  @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition convertCharacterSet(DcmSpecificCharacterSet &converter);
+
     /** print all elements of the item to a stream
      *  @param out output stream
      *  @param flags optional flag used to customize the output (see DCMTypes::PF_xxx)
@@ -226,14 +298,13 @@ public:
                        const char *pixelFileName = NULL,
                        size_t *pixelCounter = NULL);
 
-
     /** This function reads the information of all attributes which
      *  are captured in the input stream and captures this information
      *  in elementList. Each attribute is represented as an element
      *  in this list. If not all information for an attribute could be
      *  read from the stream, the function returns EC_StreamNotifyClient.
      *  @param inStream      The stream which contains the information.
-     *  @param xfer         The transfer syntax which was used to encode
+     *  @param xfer          The transfer syntax which was used to encode
      *                       the information in inStream.
      *  @param glenc         Encoding type for group length; specifies
      *                       what will be done with group length tags.
@@ -264,7 +335,7 @@ public:
      *  for a DICOM object with a given attribute within a given container,
      *  hierarchically, from a starting position identified through a cursor stack.
      *  @param xtag the DICOM attribute tag we are searching for
-     *  @param resultStack Depending on the search mode (see below), this parameter
+     *  @param resultStack depending on the search mode (see below), this parameter
      *     either serves as an input and output parameter, or as an output parameter
      *     only (the latter being the default). When used as an input parameter,
      *     the cursor stack defines the start position for the search within a
@@ -301,7 +372,7 @@ public:
      */
     virtual OFCondition assignToMRDR(DcmDirectoryRecord *mrdr );    // in
 
-    /** open a DICOM file and make this directory record into adirectory
+    /** open a DICOM file and make this directory record into a directory
      *  record for that DICOM file. The most relevant record keys
      *  (SOP Class UID, SOP instance UID, Transfer Syntax UID) are inserted
      *  into the directory record.
@@ -310,15 +381,17 @@ public:
      *  @return EC_Normal upon success, an error code otherwise
      */
     virtual OFCondition assignToSOPFile(const char *referencedFileID,
-                                        const char *sourceFileName);
+                                        const OFFilename &sourceFileName);
 
     /// return number of directory records that are child record of this one
-    virtual unsigned long cardSub();
+    virtual unsigned long cardSub() const;
 
     /** insert a child directory record
-     *  @param dirRec directory record to be inserted. Must be allocated on heap, ownership is transferred to this object
+     *  @param dirRec directory record to be inserted. Must be allocated on heap, ownership is
+     *    transferred to this object
      *  @param where index where to insert object
-     *  @param before flag indicating whether to insert the record before or after the element identified by where
+     *  @param before flag indicating whether to insert the record before or after the element
+     *    identified by where
      *  @return EC_Normal upon success, an error code otherwise
      */
     virtual OFCondition insertSub(DcmDirectoryRecord* dirRec,
@@ -380,12 +453,12 @@ public:
     virtual OFCondition clearSub();
 
     /** store the filename from which this directory record was read from
-     *  @param fname filename, must not be NULL
+     *  @param fname filename, must not be empty
      */
-    virtual void setRecordsOriginFile(const char *fname);
+    virtual void setRecordsOriginFile(const OFFilename &fname);
 
-    /// get the filename from which this directory record was read from, NULL f not set
-    virtual const char* getRecordsOriginFile();
+    /// get the filename from which this directory record was read from, empty if not set
+    virtual const OFFilename &getRecordsOriginFile();
 
     /// get the offset in file of this directory record
     Uint32 getFileOffset() const;
@@ -409,7 +482,6 @@ protected:
     Uint16              lookForRecordInUseFlag();
     Uint32              setFileOffset(Uint32 position);
 
-
     // access to MRDR data element:
     OFCondition         setNumberOfReferences(Uint32 newRefNum);
     Uint32              lookForNumberOfReferences();
@@ -417,16 +489,23 @@ protected:
     Uint32              decreaseRefNum();
 
     // misc:
+    /** Load all necessary info for this directory record.
+     *  @param referencedFileID file ID that is being referenced, may be NULL
+     *  @param sourceFileName filename for the DICOM file, may be empty (unspecified)
+     *  @param fileFormat If not NULL, then this should be the result of loading
+     *         sourceFileName. May only be non-NULL if sourceFileName isn't empty.
+     */
     OFCondition         fillElementsAndReadSOP(const char *referencedFileID,
-                                               const char *sourceFileName);
+                                               const OFFilename &sourceFileName,
+                                               DcmFileFormat *fileFormat = NULL);
     OFCondition         masterInsertSub(DcmDirectoryRecord *dirRec,
                                         const unsigned long where = DCM_EndOfListIndex);
     OFCondition         purgeReferencedFile();
 
 private:
 
-    /// string in which the filename (path) of the file from which this directory record was read is kept
-    char *recordsOriginFile;
+    /// filename (path) of the file from which this directory record was read
+    OFFilename recordsOriginFile;
 
     /// list of child directory records, kept in a sequence of items
     DcmSequenceOfItems *lowerLevelList;
@@ -447,192 +526,3 @@ private:
 
 
 #endif // DCDIRREC_H
-
-
-/*
-** CVS/RCS Log:
-** $Log: dcdirrec.h,v $
-** Revision 1.47  2010-11-15 13:58:43  uli
-** Fixed some errors in doxygen comments.
-**
-** Revision 1.46  2010-11-05 13:11:11  joergr
-** Added support for new directory record types IMPLANT, IMPLANT GROUP and
-** IMPLANT ASSY from Supplement 131 (Implant Templates).
-**
-** Revision 1.45  2010-10-14 13:15:40  joergr
-** Updated copyright header. Added reference to COPYRIGHT file.
-**
-** Revision 1.44  2010-10-01 08:06:16  joergr
-** Added new directory record type MEASUREMENT from Supplement 144.
-**
-** Revision 1.43  2010-09-30 16:43:18  joergr
-** Added new directory record types HL7 STRUC DOC, PALETTE and SURFACE.
-**
-** Revision 1.42  2010-03-01 09:08:44  uli
-** Removed some unnecessary include directives in the headers.
-**
-** Revision 1.41  2010-02-22 11:39:53  uli
-** Remove some unneeded includes.
-**
-** Revision 1.40  2008-07-17 11:19:48  onken
-** Updated copyFrom() documentation.
-**
-** Revision 1.39  2008-07-17 10:30:23  onken
-** Implemented copyFrom() method for complete DcmObject class hierarchy, which
-** permits setting an instance's value from an existing object. Implemented
-** assignment operator where necessary.
-**
-** Revision 1.38  2008-06-03 13:41:40  meichel
-** DcmDirectoryRecord::getFileOffset() is now const and public.
-**
-** Revision 1.37  2007/11/29 14:30:35  meichel
-** Updated doxygen API documentation
-**
-** Revision 1.36  2007/06/29 14:17:49  meichel
-** Code clean-up: Most member variables in module dcmdata are now private,
-**   not protected anymore.
-**
-** Revision 1.35  2007/02/19 15:04:34  meichel
-** Removed searchErrors() methods that are not used anywhere and added
-**   error() methods only in the DcmObject subclasses where really used.
-**
-** Revision 1.34  2006/08/16 09:41:26  joergr
-** Added missing CVS log entry.
-**
-** Revision 1.33  2006/08/15 15:49:56  meichel
-** Updated all code in module dcmdata to correctly compile when
-**   all standard C++ classes remain in namespace std.
-**
-** Revision 1.32  2006/07/27 13:05:05  joergr
-** Added support for DICOMDIR record type "STEREOMETRIC" (CP 628).
-** Renamed ERT_StructReport to ERT_SRDocument.
-**
-** Revision 1.31  2006/05/11 17:48:53  joergr
-** Fixed wrong CVS log entry.
-**
-** Revision 1.30  2006/05/11 08:53:36  joergr
-** Added "offset" attribute to DICOMDIR record items.
-**
-** Revision 1.29  2005/12/08 16:28:10  meichel
-** Changed include path schema for all DCMTK header files
-**
-** Revision 1.28  2005/10/27 13:30:20  joergr
-** Added support for Encapsulated Document, Real World Value Mapping and
-** Hanging Protocol objects to DICOMDIR tools.
-**
-** Revision 1.27  2004/07/01 12:28:25  meichel
-** Introduced virtual clone method for DcmObject and derived classes.
-**
-** Revision 1.26  2004/02/13 17:36:46  joergr
-** Added support for new directory records RAW DATA and SPECTROSCOPY introduced
-** with CP 343.
-**
-** Revision 1.25  2004/02/13 14:10:57  joergr
-** Added support for new directory records REGISTRATION and FIDUCIAL introduced
-** with supplement 73 (Spatial Registration Storage SOP Classes).
-**
-** Revision 1.24  2003/08/08 14:14:04  joergr
-** Translated remaining German comments.
-**
-** Revision 1.23  2003/08/08 14:04:16  joergr
-** Added two new methods insertSubAtCurrentPos() and nextSub() which allow for
-** a much more efficient insertion (avoids re-searching for correct position).
-**
-** Revision 1.22  2002/12/06 12:49:09  joergr
-** Enhanced "print()" function by re-working the implementation and replacing
-** the boolean "showFullData" parameter by a more general integer flag.
-** Added doc++ documentation.
-** Made source code formatting more consistent with other modules/files.
-**
-** Revision 1.21  2002/08/27 16:55:31  meichel
-** Initial release of new DICOM I/O stream classes that add support for stream
-**   compression (deflated little endian explicit VR transfer syntax)
-**
-** Revision 1.20  2001/09/25 17:19:25  meichel
-** Adapted dcmdata to class OFCondition
-**
-** Revision 1.19  2001/06/20 14:59:15  joergr
-** Added support for new SOP class Key Object Selection Document (suppl. 59).
-**
-** Revision 1.18  2001/06/01 15:48:39  meichel
-** Updated copyright header
-**
-** Revision 1.17  2000/12/14 12:47:20  joergr
-** Updated for 2000 edition of the DICOM standard (added: SR, PR, WV, SP, RT).
-**
-** Revision 1.16  2000/04/14 16:02:23  meichel
-** Removed default value from output stream passed to print() method.
-**   Required for use in multi-thread environments.
-**
-** Revision 1.15  2000/03/08 16:26:14  meichel
-** Updated copyright header.
-**
-** Revision 1.14  2000/03/03 14:05:23  meichel
-** Implemented library support for redirecting error messages into memory
-**   instead of printing them to stdout/stderr for GUI applications.
-**
-** Revision 1.13  2000/02/10 10:50:50  joergr
-** Added new feature to dcmdump (enhanced print method of dcmdata): write
-** pixel data/item value fields to raw files.
-**
-** Revision 1.12  1999/03/31 09:24:36  meichel
-** Updated copyright header in module dcmdata
-**
-** Revision 1.11  1999/03/22 14:10:57  meichel
-** Added support for Structured Reports to dcmgpdir.
-**   Added preliminary support for including sequences into a DICOMDIR.
-**
-** Revision 1.10  1998/07/15 15:48:46  joergr
-** Removed several compiler warnings reported by gcc 2.8.1 with
-** additional options, e.g. missing copy constructors and assignment
-** operators, initialization of member variables in the body of a
-** constructor instead of the member initialization list, hiding of
-** methods by use of identical names, uninitialized member variables,
-** missing const declaration of char pointers. Replaced tabs by spaces.
-**
-** Revision 1.9  1997/07/21 08:00:45  andreas
-** - Corrected error in DcmDirectoryRecord::write since this routine can
-**   change the length of the record after this is calculated in the
-**   sequence.
-** - DcmDirectoryRecord can be build with a referenced Name and a source
-**   filename. These name now can differ (lower case - upper case
-**   characters).
-** - Replace all boolean types (BOOLEAN, CTNBOOLEAN, DICOM_BOOL, BOOL)
-**   with one unique boolean type OFBool.
-**
-** Revision 1.8  1997/07/07 07:42:04  andreas
-** - Changed parameter type DcmTag & to DcmTagKey & in all search functions
-**   in DcmItem, DcmSequenceOfItems, DcmDirectoryRecord and DcmObject
-**
-** Revision 1.7  1997/05/16 08:31:21  andreas
-** - Revised handling of GroupLength elements and support of
-**   DataSetTrailingPadding elements. The enumeratio E_GrpLenEncoding
-**   got additional enumeration values (for a description see dctypes.h).
-**   addGroupLength and removeGroupLength methods are replaced by
-**   computeGroupLengthAndPadding. To support Padding, the parameters of
-**   element and sequence write functions changed.
-**
-** Revision 1.6  1997/05/09 13:12:02  hewett
-** Added a member variable and associated get/set methods to DcmDirectoryRecord
-** to allow the origin of a directory record to be noted.
-**
-** Revision 1.5  1997/05/06 09:22:35  hewett
-** Added a "before" flag to the insertion of items for compatibility with
-** insertion in normal Sequences.
-**
-** Revision 1.4  1997/03/26 16:56:25  hewett
-** Removed the DcmDirectoryRecord member function fillTypeElements since it
-** did nothing useful.  Smoothed out some poor indentation.
-**
-** Revision 1.3  1996/08/05 08:45:20  andreas
-** new print routine with additional parameters:
-**         - print into files
-**         - fix output length for elements
-** corrected error in search routine with parameter ESM_fromStackTop
-**
-** Revision 1.2  1996/01/05 13:22:54  andreas
-** - changed to support new streaming facilities
-** - more cleanups
-** - merged read / write methods for block and file transfer
-**
-*/
