@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2007-2010, OFFIS e.V.
+ *  Copyright (C) 2007-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -17,17 +17,10 @@
  *
  *  Purpose: Implements utility for converting standard image formats to DICOM
  *
- *  Last Update:      $Author: uli $
- *  Update Date:      $Date: 2010-11-01 10:42:44 $
- *  CVS/RCS Revision: $Revision: 1.15 $
- *  Status:           $State: Exp $
- *
- *  CVS/RCS Log at end of file
- *
  */
 
 
-#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmdata/libi2d/i2d.h"
 #include "dcmtk/dcmdata/dcpxitem.h"
@@ -37,14 +30,7 @@
 #include "dcmtk/dcmdata/dcpixseq.h"  /* for DcmPixelSequence */
 #include "dcmtk/dcmdata/dcpath.h"    /* for override keys */
 
-OFLogger DCM_dcmdataLibi2dGetLogger()
-{
-    // We don't just use a global variable, because constructors of globals are
-    // executed in random order. This guarantees that the OFLogger is constructed
-    // before first use.
-    static OFLogger DCM_dcmdata_libi2dLogger = OFLog::getLogger("dcmtk.dcmdata.libi2d");
-    return DCM_dcmdata_libi2dLogger;
-}
+OFLogger DCM_dcmdataLibi2dLogger = OFLog::getLogger("dcmtk.dcmdata.libi2d");
 
 
 Image2Dcm::Image2Dcm() : m_overrideKeys(), m_templateFile(""),
@@ -70,7 +56,7 @@ OFCondition Image2Dcm::convert(I2DImgSource *inputPlug,
   DCMDATA_LIBI2D_DEBUG("Image2Dcm: Starting conversion of file: " << inputPlug->getImageFile());
 
   // If specified, copy DICOM template file to export file
-  if (m_templateFile.length() != 0)
+  if (!m_templateFile.empty())
   {
     DcmFileFormat dcmff;
     cond = dcmff.loadFile(m_templateFile.c_str());
@@ -212,7 +198,7 @@ void Image2Dcm::cleanupTemplate(DcmDataset *targetDset)
 OFCondition Image2Dcm::applyStudyOrSeriesFromFile(DcmDataset *targetDset)
 {
   DCMDATA_LIBI2D_DEBUG("Image2Dcm: Applying study and/or series information from file");
-  if ( (!m_readSeriesLevel && !m_readStudyLevel) || (m_studySeriesFile.length() == 0) )
+  if ( (!m_readSeriesLevel && !m_readStudyLevel) || m_studySeriesFile.empty() )
     return EC_IllegalCall;
   DcmFileFormat dcmff;
   OFString errMsg;
@@ -365,7 +351,7 @@ OFCondition Image2Dcm::generateUIDs(DcmDataset *dset)
   if (!m_readSeriesLevel)
   {
     cond = dset->findAndGetOFString(DCM_SeriesInstanceUID, value);
-    if (cond.bad() || (value.length() == 0))
+    if (cond.bad() || value.empty())
     {
       char newUID[100];
       dcmGenerateUniqueIdentifier(newUID, SITE_SERIES_UID_ROOT);
@@ -380,7 +366,7 @@ OFCondition Image2Dcm::generateUIDs(DcmDataset *dset)
   if (!m_readStudyLevel)
   {
     cond = dset->findAndGetOFString(DCM_StudyInstanceUID, value);
-    if (cond.bad() || (value.length() == 0))
+    if (cond.bad() || value.empty())
     {
       char newUID[100];
       dcmGenerateUniqueIdentifier(newUID, SITE_STUDY_UID_ROOT);
@@ -393,7 +379,7 @@ OFCondition Image2Dcm::generateUIDs(DcmDataset *dset)
 
   // Generate SOP Instance UID if not already present
   cond = dset->findAndGetOFString(DCM_SOPInstanceUID, value);
-  if (cond.bad() || (value.length() == 0))
+  if (cond.bad() || value.empty())
   {
     char newUID[100];
     dcmGenerateUniqueIdentifier(newUID, SITE_INSTANCE_UID_ROOT);
@@ -421,12 +407,12 @@ OFCondition Image2Dcm::insertEncapsulatedPixelData(DcmDataset* dset,
 
   DCMDATA_LIBI2D_DEBUG("Image2Dcm: Storing imported pixel data to DICOM file");
   // create initial pixel sequence
-  DcmPixelSequence* pixelSequence = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
+  DcmPixelSequence* pixelSequence = new DcmPixelSequence(DCM_PixelSequenceTag);
   if (pixelSequence == NULL)
     return EC_MemoryExhausted;
 
   // insert empty offset table into sequence
-  DcmPixelItem *offsetTable = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
+  DcmPixelItem *offsetTable = new DcmPixelItem(DCM_PixelItemTag);
   if (offsetTable == NULL)
   {
     delete pixelSequence; pixelSequence = NULL;
@@ -440,10 +426,10 @@ OFCondition Image2Dcm::insertEncapsulatedPixelData(DcmDataset* dset,
     return cond;
   }
 
-  // store compressed frame into pixel seqeuence
+  // store compressed frame into pixel sequence
   DcmOffsetList dummyList;
   cond = pixelSequence->storeCompressedFrame(dummyList, OFreinterpret_cast(Uint8*,pixData), length, 0);
-  // storeCompressedFrame(..) does a deep copy, so the pixdata memory can be freed now
+  // storeCompressedFrame(..) does a deep copy, so the pixData memory can be freed now
   delete[] pixData;
   if (cond.bad())
   {
@@ -693,10 +679,10 @@ OFString Image2Dcm::checkAndInventType1Attrib(const DcmTagKey& key,
       err += "\n";
       return err;
     }
-    //holds element to insert in item
+    // holds element to insert in item
     elem = NULL;
     DcmTag tag(key); OFBool wasError = OFFalse;
-    //if dicom element could be created, insert in to item and modify to value
+    // if DICOM element could be created, insert in to item and modify to value
     if ( newDicomElement(elem, tag).good())
     {
         if (targetDset->insert(elem, OFTrue).good())
@@ -745,63 +731,3 @@ Image2Dcm::~Image2Dcm()
 {
   DCMDATA_LIBI2D_DEBUG("Freeing memory");
 }
-
-
-/*
- * CVS/RCS Log:
- * $Log: i2d.cc,v $
- * Revision 1.15  2010-11-01 10:42:44  uli
- * Fixed some compiler warnings reported by gcc with additional flags.
- *
- * Revision 1.14  2010-10-14 13:18:23  joergr
- * Updated copyright header. Added reference to COPYRIGHT file.
- *
- * Revision 1.13  2010-08-09 13:06:03  joergr
- * Updated data dictionary to 2009 edition of the DICOM standard. From now on,
- * the official "keyword" is used for the attribute name which results in a
- * number of minor changes (e.g. "PatientsName" is now called "PatientName").
- *
- * Revision 1.12  2010-03-25 09:26:58  onken
- * Pixel data is now already marked with the correct transfer syntax in
- * memory not only when writing to disk. This permits conversion in
- * memory, e. g. for sending the converted DICOM images directly over
- * the network.
- *
- * Revision 1.11  2009-11-04 09:58:08  uli
- * Switched to logging mechanism provided by the "new" oflog module
- *
- * Revision 1.10  2009-09-30 08:05:25  uli
- * Stop including dctk.h in libi2d's header files.
- *
- * Revision 1.9  2009-09-04 13:53:09  meichel
- * Minor const iterator related changes needed to compile with VC6 with HAVE_STL
- *
- * Revision 1.8  2009-08-05 08:51:02  joergr
- * Replaced numeric tag by pre-defined tag name (DCM_PixelDataProviderURL).
- * Fixed various inconsistencies in condition text values and log messages.
- *
- * Revision 1.7  2009-07-16 14:23:23  onken
- * Extended Image2Dcm engine to also work for uncompressed pixel data input.
- *
- * Revision 1.6  2009-07-10 13:16:07  onken
- * Added path functionality for --key option and lets the code make use
- * of the DcmPath classes.
- *
- * Revision 1.5  2009-03-31 13:05:27  onken
- * Changed implementation of lossy compression attribute detection and writing.
- *
- * Revision 1.3  2009-03-27 17:49:20  onken
- * Attribute "Pixel Aspect Ratio" (as found in JFIF header) is now written
- * to DICOM dataset if not equal to 1.
- *
- * Revision 1.2  2008-01-16 16:32:31  onken
- * Fixed some empty or doubled log messages in libi2d files.
- *
- * Revision 1.1  2008-01-16 14:36:02  onken
- * Moved library "i2dlib" from /dcmdata/libsrc/i2dlib to /dcmdata/libi2d
- *
- * Revision 1.1  2007/11/08 15:55:17  onken
- * Initial checkin of img2dcm application and corresponding library i2dlib.
- *
- *
- */
